hand_evaluator
===============

`hand_evaluator` is a cliff based app for evaluating poker hands.

Installation
-------------

To install `hand_evaluator`:

	$ pip install hand_evaluator==0.0.1a

Usage
------

Once installed, use `hand_evaluator` by running the following in a terminal.

       $ hand_evaluator evaluate -e As Ks Qs Js 10s

Or enter the evaluator interactive shell by simply typing "hand_evaluator" at the command line once installed.